@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-atom-1.0.12/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: atom
-version: 1.0.9
-id: atom-1.0.9-b7c9790b36e935331097e788b224be8b
+version: 1.0.12
+id: atom-1.0.12-8c288188982eeffb6bb3dc4aac545a08
 
 license: BSD3
 copyright:
@@ -29,24 +30,24 @@ exposed-modules: Language.Atom Language.Atom.Analysis
                  Language.Atom.Scheduling Language.Atom.Unit Language.Atom.UeMap
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/atom-1.0.9
-library-dirs: /usr/local/lib/ghc/atom-1.0.9
-hs-libraries: HSatom-1.0.9
+import-dirs: /usr/local/lib/ghc/atom-1.0.12
+library-dirs: /usr/local/lib/ghc/atom-1.0.12
+hs-libraries: HSatom-1.0.12
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
-         bimap-0.2.4-d5d3ea0f52355fd367fa2e13f84b2f83
-         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
-         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
-         process-1.1.0.2-a830d25f0e9fb9c610aa641b7f5b20f9
-         syb-0.4.0-8e7e08a060d6fc361aca595c701a94d6
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bimap-0.2.4-a4c1816183c6a7783d947addc50fde95
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         process-1.2.0.0-891670ec11c8b086a673596aa083f351
+         syb-0.4.1-acd16ebc619c31f5db97bcd1e4196777
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-atom-1.0.9/html/atom.haddock
-haddock-html: /usr/local/share/doc/hs-atom-1.0.9/html
+haddock-interfaces: /usr/local/share/doc/hs-atom-1.0.12/html/atom.haddock
+haddock-html: /usr/local/share/doc/hs-atom-1.0.12/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
